@@ -22,6 +22,7 @@
 (declare-function ollama-buddy--find-reasoning-marker "ollama-buddy")
 (declare-function ollama-buddy--update-token-rate-display "ollama-buddy")
 (declare-function ollama-buddy--send-next-in-sequence "ollama-buddy")
+(declare-function ollama-buddy--autosave-transcript "ollama-buddy")
 
 ;; Curl-specific variables
 (defvar ollama-buddy-curl--headers-processed nil
@@ -251,14 +252,16 @@ When complete, CALLBACK is called with the status response and result."
   ;; Display content in chat buffer
   (when (buffer-live-p (get-buffer ollama-buddy--chat-buffer))
     (with-current-buffer ollama-buddy--chat-buffer
-      (let ((inhibit-read-only t)
-            (window (get-buffer-window ollama-buddy--chat-buffer t))
-            (was-at-end (= (point) (point-max))))
-        
+      (let* ((inhibit-read-only t)
+             (window (get-buffer-window ollama-buddy--chat-buffer t))
+             (old-point (and window (window-point window)))
+             (was-at-end (and window (>= old-point (point-max))))
+             (old-window-start (and window (window-start window))))
+
         ;; Insert content at end of buffer
         (save-excursion
           (goto-char (point-max))
-          
+
           ;; Handle reasoning hiding
           (let ((should-show-content t))
             (when ollama-buddy-hide-reasoning
@@ -268,10 +271,10 @@ When complete, CALLBACK is called with the status response and result."
                  ((and reasoning-marker (eq (car reasoning-marker) 'start))
                   (setq ollama-buddy--in-reasoning-section t
                         should-show-content nil)
-                  (insert (format "[%s...]" 
-                                  (capitalize 
-                                   (replace-regexp-in-string 
-                                    "[<>]" "" 
+                  (insert (format "[%s...]"
+                                  (capitalize
+                                   (replace-regexp-in-string
+                                    "[<>]" ""
                                     (cadr reasoning-marker))))))
                  ;; End of reasoning section
                  ((and reasoning-marker (eq (car reasoning-marker) 'end))
@@ -283,14 +286,21 @@ When complete, CALLBACK is called with the status response and result."
                  ;; Inside reasoning section
                  (ollama-buddy--in-reasoning-section
                   (setq should-show-content nil)))))
-            
+
             ;; Insert content if not hidden
             (when should-show-content
-              (insert content)))
-          
-          ;; Keep window at end if it was there
-          (when (and window was-at-end)
-            (set-window-point window (point-max))))))))
+              (insert content))))
+
+        ;; Window state management
+        (when window
+          (cond
+           ;; Auto-scroll enabled and was at end, follow output
+           ((and was-at-end ollama-buddy-auto-scroll)
+            (set-window-point window (point-max)))
+           ;; Otherwise restore original position
+           (t
+            (set-window-point window old-point)
+            (set-window-start window old-window-start t))))))))
 
 (defun ollama-buddy-curl--handle-completion (_json-data)
   "Handle completion of curl response."
@@ -318,24 +328,32 @@ When complete, CALLBACK is called with the status response and result."
         ;; Update chat buffer
         (when (buffer-live-p (get-buffer ollama-buddy--chat-buffer))
           (with-current-buffer ollama-buddy--chat-buffer
-            (let ((inhibit-read-only t))
+            (let ((inhibit-read-only t)
+                  (response-start ollama-buddy--response-start-position)
+                  (window (get-buffer-window ollama-buddy--chat-buffer t)))
               (goto-char (point-max))
-              
-                ;; Convert the response from markdown to org format if enabled
+
+              ;; Pulse the response region to indicate completion
+              (when (and ollama-buddy-pulse-response
+                         ollama-buddy--response-start-position)
+                (ignore-errors
+                  (pulse-momentary-highlight-region
+                   ollama-buddy--response-start-position (point))))
+
+              ;; Convert the response from markdown to org format if enabled
               (when ollama-buddy-convert-markdown-to-org
                 (let* ((converted-content (with-temp-buffer
                                             (insert ollama-buddy--current-response)
                                             (ollama-buddy--md-to-org-convert-region (point-min) (point-max))
                                             (buffer-string))))
                   (set-register ollama-buddy-default-register converted-content))
-                
-                (when (and (boundp 'ollama-buddy--response-start-position)
-                           ollama-buddy--response-start-position)
+
+                (when ollama-buddy--response-start-position
                   (ollama-buddy--md-to-org-convert-region
                    ollama-buddy--response-start-position
                    (point-max))
                   ;; Reset the marker after conversion
-                  (makunbound 'ollama-buddy--response-start-position)))
+                  (setq ollama-buddy--response-start-position nil)))
 
               (unless ollama-buddy-convert-markdown-to-org
                 (set-register ollama-buddy-default-register ollama-buddy--current-response))
@@ -347,8 +365,12 @@ When complete, CALLBACK is called with the status response and result."
                                   (plist-get last-info :tokens)
                                   (plist-get last-info :elapsed)
                                   (plist-get last-info :rate)))))
+
               (insert "\n\n*** FINISHED")
-              (ollama-buddy--prepare-prompt-area))))
+              (ollama-buddy--prepare-prompt-area)
+
+              ;; Move to prompt if response is wholly visible
+              (ollama-buddy--maybe-goto-prompt window response-start))))
         
         ;; Reset tracking variables
         (setq ollama-buddy--current-token-count 0
@@ -373,7 +395,10 @@ When complete, CALLBACK is called with the status response and result."
                  (format "Curl Finished [%d %.1f t/s]"
                          (plist-get last-info :tokens)
                          (plist-get last-info :rate)))
-              (ollama-buddy--update-status "Curl Finished")))))
+              (ollama-buddy--update-status "Curl Finished"))))
+
+        ;; Auto-save transcript after every response
+        (ollama-buddy--autosave-transcript))
     (error
      (message "Error in curl completion: %s" (error-message-string err)))))
 
@@ -406,7 +431,9 @@ When complete, CALLBACK is called with the status response and result."
 ;; Main curl send function
 
 (defun ollama-buddy-curl--send (prompt &optional specified-model)
-  "Send PROMPT using curl backend with streaming support."
+  "Send PROMPT using curl backend with streaming support.
+Cloud models are proxied through the local Ollama server which handles
+authentication via `ollama signin'."
   (unless (ollama-buddy--check-status)
     (ollama-buddy--update-status "OFFLINE")
     (user-error "Ensure Ollama is running"))
@@ -417,13 +444,14 @@ When complete, CALLBACK is called with the status response and result."
   (when ollama-buddy-show-context-percentage
     (unless (ollama-buddy--check-context-before-send)
       (user-error "Context too far over limit to send")))
-  
+
   ;; Reset curl state
   (setq ollama-buddy-curl--headers-processed nil)
-  
+
   (let* ((model-info (ollama-buddy--get-valid-model specified-model))
          (model (car model-info))
          (original-model (cdr model-info))
+         (_ (ollama-buddy--ensure-cloud-model-available model))
          (supports-vision (and ollama-buddy-vision-enabled
                                (ollama-buddy--model-supports-vision model)))
          (image-files (when supports-vision
@@ -464,6 +492,7 @@ When complete, CALLBACK is called with the status response and result."
                           base-payload))
          (payload (json-encode final-payload))
          (temp-file (make-temp-file "ollama-buddy-payload"))
+         ;; Always use local Ollama server - it proxies cloud models automatically
          (url (format "http://%s:%d/api/chat" ollama-buddy-host ollama-buddy-port))
          (process-name "ollama-chat-curl")
          (process-buffer (generate-new-buffer " *ollama-curl*")))
@@ -525,7 +554,7 @@ When complete, CALLBACK is called with the status response and result."
     ;; Write payload to temp file
     (with-temp-file temp-file
       (insert payload))
-    
+
     ;; Start curl process
     (condition-case err
         (let ((args (list
@@ -535,7 +564,7 @@ When complete, CALLBACK is called with the status response and result."
                      "--header" "Content-Type: application/json"
                      "--data-binary" (concat "@" temp-file)
                      url)))
-          
+
           ;; Add streaming-specific args
           (when ollama-buddy-streaming-enabled
             (setq args (append '("--no-buffer" "--include") args)))
