@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "ollama-buddy" "20250723.759"
-  "Ollama LLM AI Assistant ChatGPT Claude Gemini Grok Support."
+(define-package "ollama-buddy" "20260218.832"
+  "Ollama LLM AI Assistant ChatGPT Claude Gemini Grok Codestral DeepSeek OpenRouter Support."
   '((emacs "28.1"))
   :url "https://github.com/captainflasmr/ollama-buddy"
-  :commit "829bfc32aa3cb28b6f2b60f151cfe1b0b2f761f0"
-  :revdesc "829bfc32aa3c"
+  :commit "189b3aff77e160d88b216c1678fba4b3a750b821"
+  :revdesc "189b3aff77e1"
   :keywords '("applications" "tools" "convenience")
   :authors '(("James Dyer" . "captainflasmr@gmail.com"))
   :maintainers '(("James Dyer" . "captainflasmr@gmail.com")))
